local nametag, addon = ...
local DSC = _G.DataStore_Containers
if not DSC then return end

local wipe = table.wipe
local time = time
local GetVoidItemInfo = GetVoidItemInfo

local VOID_STORAGE_MAX = 80   -- local to Blizzard_VoidStorageUI.lua ><
local voidID = assert(addon.void_storage_bagID)


--[[
Rather than trying to listen to events which may or may not involve new
data, we hook the one function that's called in the case of new data.
Blizzard code runs VoidStorage_ItemsUpdate() to update the icons in each
slot, including the "crawling ants" border around items recently stored.

We do the same things that DS_Containers would do when looking at a bag,
but all merged into one block of code here, and making some safe assumptions
because so much about void storage is hardcoded:
-  nothing in void is enchanted, so no "links"
-  the API doesn't even support stacks of stuff, so no "counts"
-  the bag icon is the same one that's placed on the mouse cursor when
   hovering over the void storage NPC (a never-implementd group mode for
   shaman Astral Recall)
-  nothing with long-running cooldowns
]]
local function VoidStorage_ItemsUpdate_hook ()
	local vs = DSC.ThisCharacter.Containers['Bag'..voidID]
	local freeslots = VOID_STORAGE_MAX

	wipe(vs.cooldowns)
	wipe(vs.ids)
	wipe(vs.counts)
	wipe(vs.links)
	vs.size = VOID_STORAGE_MAX
	-- bagtype 0 is "normal storage", i.e., not a profession bag; these don't
	-- seem to have named constants defined
	vs.bagtype = 0
	vs.icon = [[Interface\ICONS\Spell_Nature_AstralRecalGroup]]  -- that's right, "Recal"
	vs.link = VOID_STORAGE

	for i = 1, VOID_STORAGE_MAX do
		local itemID, textureName = GetVoidItemInfo(i)
		if itemID then
			--print("slot", i, itemID)
			freeslots = freeslots - 1
			vs.ids[i] = itemID
		end
	end
	vs.freeslots = freeslots
	DSC.ThisCharacter.lastUpdate = time()
end

function addon:VoidStorageKludges()
	--DSC:RegisterEvent("VOID_STORAGE_UPDATE", OnVoidStorageUpdate)
	--DSC:RegisterEvent("VOID_TRANSFER_DONE", OnVoidTransferDone)
	LibStub("AceHook-3.0").SecureHook (addon,
		'VoidStorage_ItemsUpdate', VoidStorage_ItemsUpdate_hook)
end

-- vim:noet
